@@ -245,9 +245,9 @@ END
    my $pemfile=$pem_file;
    $pemfile=~s/\.pem\s*$//s;
    my $type=$main::aws->{kali}->{type};
-   $type=~s/^t2/t1/;
-   $type=~s/^m2/m1/;
-   $type=~s/^m3/m1/;
+   #$type=~s/^t2/t1/;
+   #$type=~s/^m2/m1/;
+   #$type=~s/^m3/m1/;
    my $kali=$main::aws->{kali}->{kali};
    my $s=$main::aws->{fullauto}->
       {NetworkInterfaces}->[0]->{SubnetId}||'';
@@ -271,7 +271,7 @@ my $standup_kali_linux=sub {
    my $kali="]T[{select_kali_setup}";
    $main::aws->{kali}->{kali}=$kali;
    my $i=$main::aws->{fullauto}->{ImageId}||'';
-   $i='ami-29ebb519' if $os eq 'Ubuntu';
+   $i='ami-5189a661' if $os eq 'Ubuntu';
    my $s=$main::aws->{fullauto}->
          {NetworkInterfaces}->[0]->{SubnetId}||'';
    my $g=$main::aws->{fullauto}->
